==> pgmarket-1.5.0.tar.gz: pgmarket-1.5.0/locale/us/global-common.inc.php <==
<?

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */

global $IVA;		// taken from application.inc.php if the scope is a problem
global $currency;	// taken from application.inc.php if the scope is a problem
global $weightunity;	// taken from application.inc.php if the scope is a problem

$t->set_var(array(

// With regard to the following variables:
// each locale must include them from all the other locales...
// this makes the locales not totally independent of each other :(
"Choose_italian_language" => "Mostra sito in lingua Italiana",
"Choose_english_language" => "Go to the English version of the site",
//

"IVA" => $IVA,
"currency" => $currency,
"weightunity" => $weightunity,
"Shopping" => "Shopping",
"Contact_us" => "Contact us !",
"Signup_Italy" => "Signup (Italy)",
"Signup_non_Italy" => "Signup (outside of Italy)",
"Companies_Signup" => "Companies Signup",
"Turn_Off_Frames" => "Turn off frames",
"Turn_On_Frames" => "Turn on frames",
"Turn_On_Layers_Menu" => "Turn on layers menu",
"Turn_Off_Layers_Menu" => "Turn off layers menu",
"Cart" => "Cart",
"AdvancedSearch" => "Advanced Search",
"Search_the_Catalog" => "Search the Catalog",
"At_least_a_word" => "At least a word",
"All_the_words" => "All the words",
"Case_Sensitive" => "Case Sensitive",
"Search_excl" => "Search !",
"Search_Results" => "Search Results",
"on" => "on",
"pages" => "pages",
"Special_Products" => "Special Products",
"footer_message" => $CFG->myname . " \"<i>Electronic Store - Commercio elettronico</i>\"",
"Home_Page" => "Home page",
"PgMarket_Home_Page" => $CFG->myname . " Home",
"Login" => "Login",
"PgMarket_Login" => $CFG->myname . " Login",
"PgMarket_Login_Page" => $CFG->myname . ": Login Page",
"sign_up_for_an_account_now" => "If you do not already have an account, please sign up for an account now:",
"dont_login_back_to_home_page" => "If you do not wish to login yet, <a href=\"".$CFG->firstpage."\">click here</a> to return to the home page.",
"Logout" => "Logout",
"Action" => "Action",
"back" => "back",
"BACK" => "BACK",
"Brand" => "Brand",
"Discount" => "Discount",
"Starting_from" => "starting from",
"Items" => "items",
"Weight" => "Weight",
"View_product_details" => "View product details",
"Category" => "Category",
"Categories" => "Categories",
"The_category" => "The category",
"Parent" => "Parent",
"Product" => "Product",
"Products" => "Products",
"The_product" => "The product",
"Details" => "Details",
"None_Female_Singular" => "None",
"None_Male_Singular" => "None",
"Categories_Browsing" => "Categories Browsing",
"Customer" => "Customer",
"Customer_Info" => "Customer Info",
"Phone_Contact" => "Phone Contact",
"Address" => "Address",
"Number" => "Number",
"City" => "City",
"Country" => "Country / State",
"Zip_Code" => "Zip Code",
"Phone" => "Phone",
"Fax" => "Fax",
"MobilePhone" => "Mobile Phone",
"E_mail" => "E-mail",
"Date" => "Date",
"current_date" => date("Y-m-d"),
"Bill_to" => "Bill to",
"Total_weight" => "Total weight",
"Contact" => "Contact",
"Total" => "Total",
"Order" => "Order",
"Orders" => "Orders",
"No_Orders" => "No Orders",
"No_Such_Order" => "There isn't an order with the requested identifier",
"The_order" => "The order",
"Ordered" => "Ordered",
"Ordered_By" => "Ordered By",
"Order_Details" => "Order Details",
"Order_State" => "Order State",
"Orders_States" => "Orders States",
"ID" => "ID",
"ID_and_State" => "ID - State",
"Amount" => "Amount",
"Payment_Methods" => "Payment Methods",
"Cash_On_Delivery" => "Cash On Delivery",
"Credit_Card" => "Credit Card",
"Comments_and_Special_Instructions" => "Comments / Special Instructions",
"Qty" => "Qty",
"Sub_Total" => "Sub Total",
"Delivery" => "Delivery",
"Purchase_Now" => "Purchase Now",
"Order_Completed_Successfully" => "Order Completed Successfully",
"submission_to_banca_sella" => "Credit Card payment",
"Shopping_Catalog" => "Shopping Catalog",
"Product_Details" => "Product Details",
"Product_Not_Found" => "Product Not Found",
"Checkout" => "Checkout",
"Shopping_Cart" => "Shopping Cart",
"Image" => "Image",
"Remove" => "Remove",
"Delete" => "Delete",
"Edit" => "Edit",
"Name" => "Name",
"Description" => "Description",
"Extended_Description" => "Extended Description",
"Price" => "Price",
"Current_Price" => "Current Price",
"Purchase_Price" => "Purchase Price",
"Starting_from" => "starting from",
"Reset_Form" => "Reset",
"Brand" => "Brand",
"Brands" => "Brands",
"The_brand" => "The brand",
"User" => "User",
"Username" => "Username",
"Min_Username_Length" => "(at least ". $SESSION["username_length_min"] . " characters)",
"Password" => "Password",
"Old_Password" => "Old Password",
"New_Password" => "New Password",
"Password_Confirm" => "Password (confirm)",
"Confirm_Password" => "Confirm Password",
"Change_Password" => "Change Password",
"First_Name" => "First Name",
"Last_Name" => "Last Name",
"Company_Name" => "Company Name",
"Fiscal_Code" => "Fiscal Code",
"Company_identification_number" => "Company identification number",
"Company_Id_N" => "Company Id. N.",
"I_agree_to_the_usage_of_the_data_provided" => "I agree to the usage of the data provided",
"I_accept_advertising_material" => "I accept advertising material",
"I_agree_to_the_use_of_my_personal_data" => "I agree to the use of my personal data",
"Message" => "Message",
"Send" => "Send",
"Notes" => "Notes",
"Contact_Us" => "Contact Us via E-mail",
"Contact_Successful" => "E-mail Successfully Sent",
"Password_Change_Successful" => "Password Change Successful",
"Change_Settings" => "Change Settings",
"Settings_Change_Successful" => "Settings Change Successful",
"Signup" => "Signup",
"Signup_Successful" => "Signup Successful",
"Orders_Log_ca" => "Orders Log - Cash On Delivery",
"Orders_Log_cc" => "Orders Log - Credit Card",
"has_been_added_female_singular" => "has been added",
"has_been_added_male_singular" => "has been added",
"has_been_updated_female_singular" => "has been updated",
"has_been_updated_male_singular" => "has been updated",
"has_been_deleted_female_singular" => "has been deleted",
"has_been_deleted_male_singular" => "has been deleted",
"there_are_errors" => "There are errors in the submitted items",
"Errors" => "Errors",

));

?>

==> pgmarket-1.5.2.tar.gz: pgmarket-1.5.2/locale/us/global-common.inc.php <==
<?php

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */

global $IVA;		// taken from application.inc.php if the scope is a problem
global $currency;	// taken from application.inc.php if the scope is a problem
global $weightunity;	// taken from application.inc.php if the scope is a problem

$t->set_var(array(

// With regard to the following variables:
// each locale must include them from all the other locales...
// this makes the locales not totally independent of each other :(
"Choose_italian_language" => "Mostra sito in lingua Italiana",
"Choose_english_language" => "Go to the English version of the site",
//

"IVA" => $IVA,
"currency" => $currency,
"weightunity" => $weightunity,
"Shopping" => "Shopping",
"Contact_us" => "Contact us !",
"Signup_Italy" => "Signup (Italy)",
"Signup_non_Italy" => "Signup (outside of Italy)",
"Companies_Signup" => "Companies Signup",
"Turn_Off_Frames" => "Turn off frames",
"Turn_On_Frames" => "Turn on frames",
"Turn_On_Layers_Menu" => "Turn on layers menu",
"Turn_Off_Layers_Menu" => "Turn off layers menu",
"Cart" => "Cart",
"AdvancedSearch" => "Advanced Search",
"Search_the_Catalog" => "Search the Catalog",
"At_least_a_word" => "At least a word",
"All_the_words" => "All the words",
"Case_Sensitive" => "Case Sensitive",
"Search_excl" => "Search !",
"Search_Results" => "Search Results",
"on" => "on",
"pages" => "pages",
"Special_Products" => "Special Products",
"footer_message" => "$CFG->myname" . " \"<i>Electronic Store - Commercio elettronico</i>\"",
"Home_Page" => "Home page",
"PgMarket_Home_Page" => "$CFG->myname" . " Home",
"Login" => "Login",
"PgMarket_Login" => "$CFG->myname" . " Login",
"PgMarket_Login_Page" => "$CFG->myname" . ": Login Page",
"sign_up_for_an_account_now" => "If you do not already have an account, please sign up for an account now:",
"dont_login_back_to_home_page" => "If you do not wish to login yet, <a href=\"" . "$CFG->firstpage" . "\">click here</a> to return to the home page.",
"Logout" => "Logout",
"Action" => "Action",
"back" => "back",
"BACK" => "BACK",
"Discount" => "Discount",
"Starting_from" => "starting from",
"Items" => "items",
"Weight" => "Weight",
"View_product_details" => "View product details",
"Category" => "Category",
"Categories" => "Categories",
"The_category" => "The category",
"Parent" => "Parent",
"Product" => "Product",
"Products" => "Products",
"The_product" => "The product",
"Product_Code" => "Code",
"Details" => "Details",
"None_Female_Singular" => "None",
"None_Male_Singular" => "None",
"Categories_Browsing" => "Categories Browsing",
"Customer" => "Customer",
"Customer_Info" => "Customer Info",
"Phone_Contact" => "Phone Contact",
"Address" => "Address",
"Number" => "Number",
"City" => "City",
"Country" => "Country / State",
"Zip_Code" => "Zip Code",
"Phone" => "Phone",
"Fax" => "Fax",
"MobilePhone" => "Mobile Phone",
"E_mail" => "E-mail",
"Date" => "Date",
"current_date" => date("Y-m-d"),
"Bill_to" => "Bill to",
"Total_weight" => "Total weight",
"Contact" => "Contact",
"Total" => "Total",
"Order" => "Order",
"Orders" => "Orders",
"No_Orders" => "No Orders",
"No_Such_Order" => "There isn't an order with the requested identifier",
"The_order" => "The order",
"Ordered" => "Ordered",
"Ordered_By" => "Ordered By",
"Order_Details" => "Order Details",
"Order_State" => "Order State",
"Orders_States" => "Orders States",
"ID" => "ID",
"ID_and_State" => "ID - State",
"Amount" => "Amount",
"Payment_Methods" => "Payment Methods",
"Cash_On_Delivery" => "Cash On Delivery",
"Credit_Card" => "Credit Card",
"Comments_and_Special_Instructions" => "Comments / Special Instructions",
"Qty" => "Qty",
"Sub_Total" => "Sub Total",
"Delivery" => "Delivery",
"Purchase_Now" => "Purchase Now",
"Order_Completed_Successfully" => "Order Completed Successfully",
"submission_to_banca_sella" => "Credit Card payment",
"Shopping_Catalog" => "Shopping Catalog",
"Product_Details" => "Product Details",
"Product_Not_Found" => "Product Not Found",
"Checkout" => "Checkout",
"Shopping_Cart" => "Shopping Cart",
"Image" => "Image",
"Remove" => "Remove",
"Delete" => "Delete",
"Edit" => "Edit",
"Name" => "Name",
"Description" => "Description",
"Extended_Description" => "Extended Description",
"Price" => "Price",
"Current_Price" => "Current Price",
"Purchase_Price" => "Purchase Price",
"Reset_Form" => "Reset",
"Brand" => "Brand",
"Brands" => "Brands",
"The_brand" => "The brand",
"User" => "User",
"Username" => "Username",
"Min_Username_Length" => "(at least ". $SESSION["username_length_min"] . " characters)",
"Password" => "Password",
"Old_Password" => "Old Password",
"New_Password" => "New Password",
"Password_Confirm" => "Password (confirm)",
"Confirm_Password" => "Confirm Password",
"Change_Password" => "Change Password",
"First_Name" => "First Name",
"Last_Name" => "Last Name",
"Company_Name" => "Company Name",
"Fiscal_Code" => "Fiscal Code",
"Company_identification_number" => "Company identification number",
"Company_Id_N" => "Company Id. N.",
"I_agree_to_the_usage_of_the_data_provided" => "I agree to the usage of the data provided",
"I_accept_advertising_material" => "I accept advertising material",
"I_agree_to_the_use_of_my_personal_data" => "I agree to the use of my personal data",
"Message" => "Message",
"Send" => "Send",
"Notes" => "Notes",
"Contact_Us" => "Contact Us via E-mail",
"Contact_Successful" => "E-mail Successfully Sent",
"Password_Change_Successful" => "Password Change Successful",
"Change_Settings" => "Change Settings",
"Settings_Change_Successful" => "Settings Change Successful",
"Signup" => "Signup",
"Signup_Successful" => "Signup Successful",
"Orders_Log_ca" => "Orders Log - Cash On Delivery",
"Orders_Log_cc" => "Orders Log - Credit Card",
"has_been_added_female_singular" => "has been added",
"has_been_added_male_singular" => "has been added",
"has_been_updated_female_singular" => "has been updated",
"has_been_updated_male_singular" => "has been updated",
"has_been_deleted_female_singular" => "has been deleted",
"has_been_deleted_male_singular" => "has been deleted",
"there_are_errors" => "There are errors in the submitted items",
"Errors" => "Errors",

));

?>
